==> haskell-open-browser-0.2.1.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-open-browser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: open-browser
version: 0.2.1.0
id: open-browser-0.2.1.0-IlmBbUU5IZGH2cVeTpoTFu
key: open-browser-0.2.1.0-IlmBbUU5IZGH2cVeTpoTFu
license: BSD3
maintainer: rightfold@gmail.com
homepage: https://github.com/rightfold/open-browser
synopsis: Open a web browser from Haskell.
description:
    Open a web browser from Haskell.
    Currently BSD, Linux, OS X and Windows are supported.
category: Web
author: rightfold
exposed: True
indefinite: False
exposed-modules:
    Web.Browser
hidden-modules: Web.Browser.Linux Web.Browser.OSX
abi: 38f78d039c8ba19bba458d4d71f53562
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/open-browser-0.2.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/open-browser-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/open-browser-0.2.1.0
hs-libraries: HSopen-browser-0.2.1.0-IlmBbUU5IZGH2cVeTpoTFu
depends:
    base-4.10.1.0 process-1.6.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
haddock-interfaces: /usr/share/doc/haskell-open-browser/html/open-browser.haddock
haddock-html: /usr/share/doc/haskell-open-browser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-open-browser-0.2.1.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-open-browser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: open-browser
version: 0.2.1.0
id: open-browser-0.2.1.0-Lj74S9sKrTXAgLlyjQqhhk
key: open-browser-0.2.1.0-Lj74S9sKrTXAgLlyjQqhhk
license: BSD-3-Clause
maintainer: rightfold@gmail.com
author: rightfold
homepage: https://github.com/rightfold/open-browser
synopsis: Open a web browser from Haskell.
description:
    Open a web browser from Haskell.
    Currently BSD, Linux, OS X and Windows are supported.
category: Web
abi: 17ae4bc4eb3b20d47d3ae77c0acbe280
exposed: True
exposed-modules:
    Web.Browser
hidden-modules: Web.Browser.Linux Web.Browser.OSX
import-dirs: /usr/lib/ghc-8.4.2/site-local/open-browser-0.2.1.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/open-browser-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/open-browser-0.2.1.0
hs-libraries: HSopen-browser-0.2.1.0-Lj74S9sKrTXAgLlyjQqhhk
depends:
    base-4.11.1.0 process-1.6.3.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
haddock-interfaces: /usr/share/doc/haskell-open-browser/html/open-browser.haddock
haddock-html: /usr/share/doc/haskell-open-browser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
